# frozen_string_literal: true

#
# This function filters unsupported jvm options.
#
#
# See the file "LICENSE" for the full license governing this code.
#
Puppet::Functions.create_function(:'wls_install::filter_unsupported_jvm_options') do
  dispatch :filter_unsupported_jvm_options do
    param 'String', :jvm_options
    param 'Integer', :jvm_version
    return_type 'String'
  end

  def filter_unsupported_jvm_options(jvm_options, jvm_version)
    options_array = jvm_options.split
    case jvm_version
    when 7
      exclude = []
    when 8
      exclude = ['XX:MaxPermSize', 'XX:PermSize']
    else
      "Version #{jvm_version} is not supported. Only version 7 and 8 are."
    end
    filtered_options = options_array.select { |o| exclude.none? { |e| o.include?(e) } }
    filtered_options.join(' ')
  end
end
