#
# wls_install::ords::software_version
#
# @summary This defined type allows you to install specified version of ords software.
#
#
# @param [String[1]] file
#    The name of the ords install file.
#
# @param [Stdlib::Absolutepath] ords_home
#    The ords home path.
#
# @param [String[1]] source
#    Source for the operation.
#
# @param [Stdlib::Absolutepath] temp_dir
#    The temporary directory path.
#
# @param [Variant[Enum['on_failure'], Boolean]] logoutput
#    log the outputs of Puppet exec or not.
#    When you specify `true` Puppet will log all output of `exec` types.
#    Valid values are:
#    - `true`
#    - `false`
#    - `on_failure`
#
#
# See the file "LICENSE" for the full license governing this code.
#
define wls_install::ords::software_version (
  String[1]                            $source,
  String[1]                            $file,
  Stdlib::Absolutepath                 $ords_home,
  Stdlib::Absolutepath                 $temp_dir        = '/tmp',
  Variant[Enum['on_failure'], Boolean] $logoutput       = 'on_failure',
) {
  if $facts['os']['family'] == 'windows' { fail 'This module does not support Windows' }

  $version = $title
  assert_type(Pattern[/\d+\.\d+\.\d+\.\d/], $version) |$expected, $actual| {
    fail 'Invalid version specified'
  }
  $version_components = $version.split('\.')
  $major_version      = "${version_components[0]}.${version_components[1]}.${version_components[2]}"
  #
  # If the installed version is the same as the requested version. Do nothing
  #
  easy_type::debug_evaluation() # Show local variable on extended debug

  unless wls_install::ords_installed($ords_home, $major_version) {
    $ords_dirs = [
      $ords_home,
      "${ords_home}/config",
      "${ords_home}/log",
    ]

    file { $ords_dirs:
      ensure => 'directory',
    }
    -> archive { "${temp_dir}/${file}":
      ensure       => present,
      extract      => true,
      extract_path => $ords_home,
      source       => "${source}/${file}",
      cleanup      => true,
      creates      => '/always/extract/the_file',
    }
    file { '/etc/ords_homes':
      ensure => 'file',
      mode   => '0755',
    }

    -> file_line { "Mark ords home ${ords_home}":
      ensure => 'present',
      path   => '/etc/ords_homes',
      line   => $ords_home,
    }
  }
}
